@@ -51,7 +51,8 @@ class _Sentinel(object):
     __str__ = __repr__
 
 UNSPECIFIED = _Sentinel('UNSPECIFIED')
-ALL_METHODS = re.compile('.*')
+ABSOLUTELLY_ALL_METHODS = re.compile('.*')
+ALL_METHODS = re.compile('(?!__getattribute__$)')
 NORMAL_METHODS = re.compile('(?!__.*__$)')
 REGEX_TYPE = type(NORMAL_METHODS)
 VALID_IDENTIFIER = re.compile(r'^[^\W\d]\w*$', re.UNICODE if PY3 else 0)
@@ -332,7 +333,7 @@ def weave_class(klass, aspect, methods=NORMAL_METHODS, subclasses=True, lazy=Fal
             super(SubClass, self).__init__(*args, **kwargs)
             for attr in dir(self):
                 func = getattr(self, attr, None)
-                if method_matches(attr) and attr not in wrappers and callable(func):
+                if method_matches(attr) and attr not in wrappers and isroutine(func):
                     setattr(self, attr, checked_apply(aspect, force_bind(func)).__get__(self, SubClass))
 
         wrappers = {
